Bucket

Type Alias Bucket 

pub type Bucket = (Vec<u8>, Vec<u8>, u64);
One value bucket: the identity a cross-shard merge sums by, a spelling of it that occurs in the corpus, and how many documents matched with it.